[Lldb-commits] [lldb] r234071 - Use insert instead of append when adding to sys.path.

Chaoren Lin chaorenl at google.com
Fri Apr 3 18:11:31 PDT 2015


Author: chaoren
Date: Fri Apr  3 20:11:31 2015
New Revision: 234071

URL: http://llvm.org/viewvc/llvm-project?rev=234071&view=rev
Log:
Use insert instead of append when adding to sys.path.

Similar problem as in the last part of r200486.

Modified:
    lldb/trunk/test/dotest.py

Modified: lldb/trunk/test/dotest.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/dotest.py?rev=234071&r1=234070&r2=234071&view=diff
==============================================================================
--- lldb/trunk/test/dotest.py (original)
+++ lldb/trunk/test/dotest.py Fri Apr  3 20:11:31 2015
@@ -928,13 +928,13 @@ def setupSysPath():
     # use that version.
     sys.path.insert(0, pexpectPath)
 
-    # Append script dir, plugin dir, lldb-mi dir and lldb-server dir to the sys.path.
-    sys.path.append(scriptPath)
-    sys.path.append(pluginPath)
-    sys.path.append(toolsLLDBMIPath)     # Adding test/tools/lldb-mi to the path makes it easy
-                                         # to "import lldbmi_testcase" from the MI tests
-    sys.path.append(toolsLLDBServerPath) # Adding test/tools/lldb-server to the path makes it easy
-                                         # to "import lldbgdbserverutils" from the lldb-server tests
+    # Insert script dir, plugin dir, lldb-mi dir and lldb-server dir to the sys.path.
+    sys.path.insert(0, scriptPath)
+    sys.path.insert(0, pluginPath)
+    sys.path.insert(0, toolsLLDBMIPath)      # Adding test/tools/lldb-mi to the path makes it easy
+                                             # to "import lldbmi_testcase" from the MI tests
+    sys.path.insert(0, toolsLLDBServerPath)  # Adding test/tools/lldb-server to the path makes it easy
+                                             # to "import lldbgdbserverutils" from the lldb-server tests
 
     # This is our base name component.
     base = os.path.abspath(os.path.join(scriptPath, os.pardir))





More information about the lldb-commits mailing list